@@ -8,7 +8,7 @@
 #'
 #' @examples
 #'
-#' \donttest{
+#' \dontrun{
 
 #'  #    Open the graphic devices
 #'
@@ -22,7 +22,7 @@
 #'
 #' #    Close the graphic device
 #'
-#'        Close_all_graphic_devices()
+#' ##       Close_all_graphic_devices()
 #'
 #'
 #'#'}# dottest
@@ -30,14 +30,14 @@
 Close_all_graphic_devices <- function(){
 
 
-if (grDevices::dev.cur()>=3) {
+# if (grDevices::dev.cur()>=4) {
 
-     for (i in 3:grDevices::dev.cur()-1)  {
-       message("\n*  The ",i,"-th graphic device is omitted.\n" ,sep = "")
-       grDevices::dev.off()
-     }
-}
-  if (grDevices::dev.cur()==1||grDevices::dev.cur()==2){
-    message("\n*  It is sufficient to run R CMD check.")
-}
+     # for (i in 3:grDevices::dev.cur()-1)  {
+     #   message("\n*  The ",i,"-th graphic device is omitted.\n" ,sep = "")
+       while (!is.null(grDevices::dev.list()))   grDevices::dev.off()
+     # }
+# }
+#   if (grDevices::dev.cur()==1||grDevices::dev.cur()==2){
+#     message("\n*  It is sufficient to run R CMD check.")
+# }
   }# function
