@@ -311,13 +311,13 @@ metadata_srsc_per_image<- function(dataList,ModifiedPoisson)
 #'
 #'\code{f }  : A vector, indicating the number of false alarm
 #'
-#'\code{NL }  : An positive integer, indicating the number of lesions for all images
+#'\code{NL }  : A positive integer, indicating the number of lesions for all images
 #'
-#'\code{C } : An positive integer, indicating the highest number of confidence level
+#'\code{C } : A positive integer, indicating the highest number of confidence level
 #'
-#'\code{M } : An positive integer, indicating the number of modalities
+#'\code{M } : A positive integer, indicating the number of modalities
 #'
-#'\code{Q } : An positive integer, indicating the number of readers.
+#'\code{Q } : A positive integer, indicating the number of readers.
 #'
 #'The detail of these dataset, please see the example datasets, e.g. \code{\link{dd}}.
 
@@ -509,7 +509,7 @@ metadata_to_fit_MRMC<- function(dataList,ModifiedPoisson=FALSE)
   ffN<-ff/NX
 
 
-  data <- list(N=N,Q=Q, M=M,m=m  ,C=C ,S=S,  NL=NL,NI=NI
+  data <- list(N=N,Q=Q, M=M,m=m  ,C=C ,S=S,  NL=NL,NI=NI, ccc = C:1
                ,c=c,q=q,
                h=h, f=f,
                hh=hh, hhN=hhN,
